@@ -6,12 +6,13 @@
  */
 
 #include "groupedappletscontainer.h"
-#include "../debug.h"
+#include "debug.h"
 
 #include <QDebug>
 
 #include <KActionCollection>
 #include <Plasma/Corona>
+#include <PlasmaQuick/AppletQuickItem>
 #include <QAction>
 
 GroupedAppletsContainer::GroupedAppletsContainer(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
@@ -82,10 +83,10 @@ void GroupedAppletsContainer::ensureSystrayExists()
     m_innerContainment->setFormFactor(formFactor());
     m_innerContainment->setLocation(location());
 
-    m_internalContainmentItem = m_innerContainment->property("_plasma_graphicObject").value<QQuickItem *>();
+    m_internalContainmentItem = PlasmaQuick::AppletQuickItem::itemForApplet(m_innerContainment);
     Q_EMIT internalContainmentItemChanged();
 
-    actions()->addAction(QStringLiteral("configure"), m_innerContainment->actions()->action(QStringLiteral("configure")));
+    setInternalAction(QStringLiteral("configure"), m_innerContainment->internalAction(QStringLiteral("configure")));
     connect(m_innerContainment.data(), &Plasma::Containment::configureRequested, this, [this](Plasma::Applet *applet) {
         Q_EMIT containment()->configureRequested(applet);
     });
@@ -96,23 +97,23 @@ void GroupedAppletsContainer::ensureSystrayExists()
     }
 
     // replace internal remove action with ours
-    m_innerContainment->actions()->addAction(QStringLiteral("remove"), actions()->action(QStringLiteral("remove")));
+    m_innerContainment->setInternalAction(QStringLiteral("remove"), internalAction(QStringLiteral("remove")));
 }
 
-void GroupedAppletsContainer::constraintsEvent(Plasma::Types::Constraints constraints)
+void GroupedAppletsContainer::constraintsEvent(Plasma::Applet::Constraints constraints)
 {
-    if (constraints & Plasma::Types::LocationConstraint) {
+    if (constraints & Plasma::Applet::LocationConstraint) {
         if (m_innerContainment) {
             m_innerContainment->setLocation(location());
         }
     }
-    if (constraints & Plasma::Types::FormFactorConstraint) {
+    if (constraints & Plasma::Applet::FormFactorConstraint) {
         if (m_innerContainment) {
             m_innerContainment->setFormFactor(formFactor());
         }
     }
 
-    if (constraints & Plasma::Types::UiReadyConstraint) {
+    if (constraints & Plasma::Applet::UiReadyConstraint) {
         ensureSystrayExists();
     }
 }
