@@ -11,7 +11,7 @@
 #include <QTest>
 
 using namespace KUnitConversion;
-using namespace Plasma;
+using namespace KRunner;
 
 class ConverterRunnerTest : public AbstractRunnerTest
 {
@@ -73,7 +73,7 @@ void ConverterRunnerTest::testLettersAndCurrency()
     launchQuery(QStringLiteral("4us$>ca$"));
 
     QCOMPARE(manager->matches().count(), 1);
-    QVERIFY(manager->matches().constFirst().text().contains(QLatin1String("Canadian dollars (CAD)")));
+    QVERIFY2(manager->matches().constFirst().text().contains(QLatin1String("Canadian dollars (CAD)")), qUtf8Printable(manager->matches().constFirst().text()));
 }
 
 /**
@@ -94,11 +94,7 @@ void ConverterRunnerTest::testQuery_data()
     QTest::addColumn<QString>("expectedText");
 
     QTest::newRow("test specific target unit") << QStringLiteral("1m > cm") << QStringLiteral("100 centimeters (cm)");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QTest::newRow("test symbols (other than currencies)") << QStringLiteral("1000 µs as year") << QStringLiteral("3.17098e-11 year (y)");
-#else
     QTest::newRow("test symbols (other than currencies)") << QStringLiteral("1000 µs as year") << QStringLiteral("3.17098E-11 year (y)");
-#endif
     QTest::newRow("test negative value") << QStringLiteral("-4m as cm") << QStringLiteral("-400 centimeters (cm)");
     QTest::newRow("test fractions") << QStringLiteral("6/3m>cm") << QStringLiteral("200 centimeters (cm)");
     QTest::newRow("test case insensitive units") << QStringLiteral("1Liter in ML") << QStringLiteral("1,000 milliliters (ml)");
@@ -142,7 +138,7 @@ void ConverterRunnerTest::testRoundingOfCurrencies()
     launchQuery(QStringLiteral("50.123$"));
     QVERIFY(!manager->matches().isEmpty());
     QRegularExpression hasTwoDecimalPrescision(QStringLiteral(R"(^\d+\.\d\d)"));
-    QVERIFY(manager->matches().constFirst().text().contains(hasTwoDecimalPrescision));
+    QVERIFY2(manager->matches().constFirst().text().contains(hasTwoDecimalPrescision), qUtf8Printable(manager->matches().constFirst().text()));
 }
 
 QTEST_MAIN(ConverterRunnerTest)
